// **********************************************************************
// 
// <copyright>
// 
//  BBN Technologies
//  10 Moulton Street
//  Cambridge, MA 02138
//  (617) 873-8000
// 
//  Copyright (C) BBNT Solutions LLC. All rights reserved.
// 
// </copyright>
// **********************************************************************
// 
// $Source: /cvs/CVS_LEBA/external/openmap/openmap/src/openmap/com/bbn/openmap/layer/util/http/HttpResponse.java,v $
// $RCSfile: HttpResponse.java,v $
// $Revision: 1.1 $
// $Date: 2006/03/21 10:25:20 $
// $Author: tomrak $
// 
// **********************************************************************

package com.bbn.openmap.layer.util.http;

import java.io.IOException;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Writer;
import java.net.Socket;

import com.bbn.openmap.util.Debug;

/**
 * HttpConnection handles the communication with an HTTP client in its
 * own thread. An instance of this class is created by the
 * <code>HttpServer</code> each time a connection is made. The
 * instance exists only long enough to fulfill the request, then dies.
 * 
 * @author Tom Mitchell
 * @version 1.1, 06/17/97
 * @see HttpServer
 */
public class HttpResponse implements IHttpResponse  {

    protected OutputStream out;

    /**
     * Initialize the input <code>Reader</code> and output
     * <code>Writer</code> and start the connection thread.
     * 
     * @param client_socket the client's socket
     * @param server the server object
     */
    public HttpResponse(OutputStream out) {
        this.out = out;
    }


    /**
     * Can be used to write the header to an HttpResponse. You need to
     * create a Writer tied to the OutputStream in order to write this
     * text.
     * 
     * @param out Writer to place text on the OutputStream.
     * @param contentType the mime type for your response.
     * @param contentLength the byte length of your response.
     */
    public void writeHttpResponseHeader(Writer writer, String contentType,
                                               int contentLength)
            throws IOException {

        writer.write("HTTP/1.0 200 \n"); // return status
        writer.write("Content-type: " + contentType + "\n"); // important!
        writer.write("Content-Length: " + contentLength + "\n"); // important!
        writer.write("\n");
    }

    /**
     * Write a String response to the OutputStream.
     * 
     * @param out the OutputStream of the response.
     * @param contentType the content type of the response.
     * @param response the string containing the response.
     */
    public void writeHttpResponse(String contentType,String response) throws IOException {

        OutputStreamWriter osw = new OutputStreamWriter(out);
        writeHttpResponseHeader(osw, contentType, response.length());
        osw.write(response);
        osw.flush();
    }

    /**
     * Write a byte[] response to the OutputStream.
     * 
     * @param out the OutputStream of the response.
     * @param contentType the content type of the response.
     * @param response the byte array containing the response.
     */
    public void writeHttpResponse(String contentType,byte[] response) throws IOException {
        OutputStreamWriter osw = new OutputStreamWriter(out);
        writeHttpResponseHeader(osw, contentType, response.length);
        osw.flush();
        out.write(response, 0, response.length);
        osw.flush();
    }

}

