/*
 * $Header: /cvs/CVS_LEBA/external/openmap/openmap/src/openmap/com/bbn/openmap/wms/WmsLayerFactory.java,v 1.1 2006/03/21 10:27:54 tomrak Exp $
 *
 * Copyright 2001-2005 OBR Centrum Techniki Morskiej, All rights reserved.
 *
 */
package com.bbn.openmap.wms;

import java.io.IOException;
import java.net.MalformedURLException;
import java.util.Map;
import java.util.HashMap;
import java.util.Properties;
import java.lang.reflect.Constructor;

import com.bbn.openmap.util.PropUtils;
import com.bbn.openmap.Layer;
import com.bbn.openmap.util.Debug;

/**
 * Class responsible for creation IWmsLayer for gi
 * @version $Header: /cvs/CVS_LEBA/external/openmap/openmap/src/openmap/com/bbn/openmap/wms/WmsLayerFactory.java,v 1.1 2006/03/21 10:27:54 tomrak Exp $
 * @author tomrak
 */
public class WmsLayerFactory  {

    private final Map<Class, Class> wmsLayersMap = new HashMap();

    public WmsLayerFactory(Properties props) throws WMSException {
        String wmsLayers = props.getProperty("wms.layers");
        try {
            for (Object key : PropUtils.parseSpacedMarkers(wmsLayers) ) {
                Class layerClass = Class.forName(props.getProperty((String)key + ".layerClass"));
                Class clazz = Class.forName(props.getProperty((String)key + ".class"));
                wmsLayersMap.put(layerClass, clazz);
            }
        } catch (ClassNotFoundException ex) {
            throw new WMSException("Problem with wmsLayers configuration");
        }
    }

    
    IWmsLayer createWmsLayer(Layer layer) {
        Class layerClass = layer.getClass();
        Class wmsLayerClass = wmsLayersMap.get(layerClass);
        if (wmsLayerClass == null) {
            return new DefaultLayerAdapter(layer);
        }
        IWmsLayer wmsLayer = null;
        try {
            Constructor constructor = wmsLayerClass.getConstructor(Layer.class);
            wmsLayer = (IWmsLayer) constructor.newInstance(layer);
        } catch (Exception ex) {
            Debug.message("ms","Problem calling constructor for class " + wmsLayerClass.getName() + ":" + ex.getMessage());
        }
        if (wmsLayer == null) {
            wmsLayer = new DefaultLayerAdapter(layer);
        }
        return wmsLayer;
    }
    
}
